group :libvirt do
  gem 'fog-libvirt', '>= 0.13.0'
  gem 'ruby-libvirt', '~> 0.5', :require => 'libvirt'
end
